@@ -26,6 +26,10 @@ class DajaxiceConfig(object):
     def dajaxice_url(self):
         return r'^%s/' % self.DAJAXICE_MEDIA_PREFIX
 
+    @property
+    def django_settings(self):
+        return settings
+
     @property
     def modules(self):
         return dajaxice_functions.modules
